import { Subject } from 'rxjs';
import { PickupGridViewBase } from '@/studio-core';
import EAMMonitorPointService from '@/service/eammonitor-point/eammonitor-point-service';
import EAMMonitorPointAuthService from '@/authservice/eammonitor-point/eammonitor-point-auth-service';
import PickupGridViewEngine from '@engine/view/pickup-grid-view-engine';
import EAMMonitorPointUIService from '@/uiservice/eammonitor-point/eammonitor-point-ui-service';

/**
 * 测点选择表格视图视图基类
 *
 * @export
 * @class EAMMonitorPointPickupGridViewBase
 * @extends {PickupGridViewBase}
 */
export class EAMMonitorPointPickupGridViewBase extends PickupGridViewBase {
    /**
     * 视图对应应用实体名称
     *
     * @protected
     * @type {string}
     * @memberof EAMMonitorPointPickupGridViewBase
     */
    protected appDeName: string = 'eammonitorpoint';

    /**
     * 应用实体主键
     *
     * @protected
     * @type {string}
     * @memberof EAMMonitorPointPickupGridViewBase
     */
    protected appDeKey: string = 'eammonitorpointid';

    /**
     * 应用实体主信息
     *
     * @protected
     * @type {string}
     * @memberof EAMMonitorPointPickupGridViewBase
     */
    protected appDeMajor: string = 'eammonitorpointname';

    /**
     * 实体服务对象
     *
     * @type {EAMMonitorPointService}
     * @memberof EAMMonitorPointPickupGridViewBase
     */
    protected appEntityService: EAMMonitorPointService = new EAMMonitorPointService;

    /**
     * 实体权限服务对象
     *
     * @type EAMMonitorPointUIService
     * @memberof EAMMonitorPointPickupGridViewBase
     */
    public appUIService: EAMMonitorPointUIService = new EAMMonitorPointUIService(this.$store);


    /**
     * 计数器服务对象集合
     *
     * @protected
     * @type {Array<*>}
     * @memberof EAMMonitorPointPickupGridViewBase
     */    
    protected counterServiceArray: Array<any> = [];

    /**
     * 视图模型数据
     *
     * @protected
     * @type {*}
     * @memberof EAMMonitorPointPickupGridViewBase
     */
    protected model: any = {
        srfCaption: 'entities.eammonitorpoint.views.pickupgridview.caption',
        srfTitle: 'entities.eammonitorpoint.views.pickupgridview.title',
        srfSubTitle: 'entities.eammonitorpoint.views.pickupgridview.subtitle',
        dataInfo: ''
    }

    /**
     * 容器模型
     *
     * @protected
     * @type {*}
     * @memberof EAMMonitorPointPickupGridViewBase
     */
    protected containerModel: any = {
        view_grid: { name: 'grid', type: 'GRID' },
        view_searchform: { name: 'searchform', type: 'SEARCHFORM' },
    };


	/**
     * 视图唯一标识
     *
     * @protected
     * @type {string}
     * @memberof ViewBase
     */
	protected viewtag: string = '91dd54198b1e7777908d564a86bc548d';


    /**
     * 视图引擎
     *
     * @public
     * @type {Engine}
     * @memberof EAMMonitorPointPickupGridViewBase
     */
    public engine: PickupGridViewEngine = new PickupGridViewEngine();

    /**
     * 引擎初始化
     *
     * @public
     * @memberof EAMMonitorPointPickupGridViewBase
     */
    public engineInit(): void {
        this.engine.init({
            view: this,
            grid: this.$refs.grid,
            searchform: this.$refs.searchform,
            keyPSDEField: 'eammonitorpoint',
            majorPSDEField: 'eammonitorpointname',
            isLoadDefault: true,
        });
    }

    /**
     * grid 部件 selectionchange 事件
     *
     * @param {*} [args={}]
     * @param {*} $event
     * @memberof EAMMonitorPointPickupGridViewBase
     */
    public grid_selectionchange($event: any, $event2?: any): void {
        this.engine.onCtrlEvent('grid', 'selectionchange', $event);
    }

    /**
     * grid 部件 beforeload 事件
     *
     * @param {*} [args={}]
     * @param {*} $event
     * @memberof EAMMonitorPointPickupGridViewBase
     */
    public grid_beforeload($event: any, $event2?: any): void {
        this.engine.onCtrlEvent('grid', 'beforeload', $event);
    }

    /**
     * grid 部件 rowdblclick 事件
     *
     * @param {*} [args={}]
     * @param {*} $event
     * @memberof EAMMonitorPointPickupGridViewBase
     */
    public grid_rowdblclick($event: any, $event2?: any): void {
        this.engine.onCtrlEvent('grid', 'rowdblclick', $event);
    }

    /**
     * grid 部件 load 事件
     *
     * @param {*} [args={}]
     * @param {*} $event
     * @memberof EAMMonitorPointPickupGridViewBase
     */
    public grid_load($event: any, $event2?: any): void {
        this.engine.onCtrlEvent('grid', 'load', $event);
    }

    /**
     * searchform 部件 save 事件
     *
     * @param {*} [args={}]
     * @param {*} $event
     * @memberof EAMMonitorPointPickupGridViewBase
     */
    public searchform_save($event: any, $event2?: any): void {
        this.engine.onCtrlEvent('searchform', 'save', $event);
    }

    /**
     * searchform 部件 search 事件
     *
     * @param {*} [args={}]
     * @param {*} $event
     * @memberof EAMMonitorPointPickupGridViewBase
     */
    public searchform_search($event: any, $event2?: any): void {
        this.engine.onCtrlEvent('searchform', 'search', $event);
    }

    /**
     * searchform 部件 load 事件
     *
     * @param {*} [args={}]
     * @param {*} $event
     * @memberof EAMMonitorPointPickupGridViewBase
     */
    public searchform_load($event: any, $event2?: any): void {
        this.engine.onCtrlEvent('searchform', 'load', $event);
    }



    /**
     * 是否展开搜索表单
     *
     * @protected
     * @type {boolean}
     * @memberof EAMMonitorPointPickupGridViewBase
     */
    protected isExpandSearchForm: boolean = true;


}